Crate kcode_rust_libs_v2

Crate kcode_rust_libs_v2 

Six-operation managed Rust-library boundary.

Structs

Error
A bounded displayable failure.
File
One complete UTF-8 source file.
Lib
One complete editable managed-library source snapshot.

Functions

create
Creates a minimal Rust 2024 library and returns its complete source.
docs
Reads only the canonical package version and root Documentation.md.
open
Opens an existing managed library and returns its complete useful source.

Type Aliases

Result
Result type returned by this crate.