pub struct KcodeRustLibs { /* private fields */ }Expand description
Manager for a persistent root of small agent-authored Rust libraries.
Implementations
Sourceimpl KcodeRustLibs
impl KcodeRustLibs
Sourcepub fn new(
rust_libs_root: impl AsRef<Path>,
crates_io_registry_token: impl AsRef<str>,
) -> Result<Self>
pub fn new( rust_libs_root: impl AsRef<Path>, crates_io_registry_token: impl AsRef<str>, ) -> Result<Self>
Creates or opens the library root and retains the publication token privately.
Sourcepub fn create_rust_lib(&self, name: &str) -> Result<OpenedRustLib>
pub fn create_rust_lib(&self, name: &str) -> Result<OpenedRustLib>
Creates a new Rust 2024 library at version 0.1.0 and opens it.
Sourcepub fn open_rust_lib(&self, name: &str) -> Result<OpenedRustLib>
pub fn open_rust_lib(&self, name: &str) -> Result<OpenedRustLib>
Opens and completely loads an existing managed Rust library.